#!/usr/bin/python
# -*- coding: utf-8 -*-

# tableModel.py
#
# This file is part of BotMU
#
# Author: Raphaël Perraudeau <r.perraudeau@gmail.com>
# Copyright: 2011 Raphaël Perraudeau <r.perraudeau@gmail.com>
# Licence: GNU/GPL
#
# Home page: <http://botmu.sourceforge.net/>


# Inclusions des modules:

# Pyqt4
from PyQt4.QtCore import *
from PyQt4.QtGui import *

from commonFunctions import *


#############################################################################
class MyTableModel(QAbstractTableModel): 
	def __init__(self, datain, headerdata, parent=None, *args): 
		QAbstractTableModel.__init__(self, parent, *args) 
		self.arraydata = datain
		self.headerdata = headerdata

	def rowCount(self, parent): 
		return len(self.arraydata) 

	def columnCount(self, parent): 
		return len(self.headerdata) 

	def data(self, index, role): 
		if not index.isValid(): 
			return QVariant()
		if role == Qt.DecorationRole and index.column()==0:
			return QImage(QPixmap(self.arraydata[index.row()][2]).scaled(20, 20, Qt.KeepAspectRatio,Qt.SmoothTransformation))
		elif role != Qt.DisplayRole: 
			return QVariant() 
		elif index.column()==2:
			if len(self.arraydata[index.row()])>4:
				return QVariant(self.arraydata[index.row()][4]) 
			else:
				return QVariant() 
		return QVariant(cutString(self.arraydata[index.row()][index.column()])) 

	def flags(self,index):
		if index.isValid():
			return (Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDragEnabled)
		return Qt.ItemIsDropEnabled
		
		
	def headerData(self, section, orientation, role):
		if orientation == Qt.Horizontal and role == Qt.DisplayRole:
			return QVariant(self.headerdata[section])
		if orientation == Qt.Vertical and role == Qt.DisplayRole:
			return QVariant(section+1)
		return QVariant()			

		
class ProgressBarDelegate(QItemDelegate):
	def __init__(self, owner, itemslist):
		QItemDelegate.__init__(self, owner)
		self.itemslist = itemslist
	
	def sizeHint(self, option, index):
		return QSize(120, 30)

	def paint(self, painter, option, index):
		percent = self.itemslist[index.row()][3]
		
		if len(self.itemslist[index.row()])<=4:
			opts = QStyleOptionProgressBarV2()
			opts.rect = option.rect
			opts.minimum = 1
			opts.maximum = 100
				
			opts.progress = percent
		
			if percent == 0:
				opts.textVisible = False
			else:
				opts.textVisible = True
				
			opts.palette.setColor(QPalette.Normal, QPalette.Text,Qt.blue);
			opts.text = QString('%d%%'%percent)
			QApplication.style().drawControl(QStyle.CE_ProgressBar, opts, painter)
		else:
			opts = QStyleOptionProgressBarV2()
			opts.rect = option.rect
			opts.minimum = 1
			opts.maximum = 100
				
			opts.progress = 0
		
			opts.textVisible = True
				
			opts.palette.setColor(QPalette.Normal, QPalette.Text,Qt.red);
			opts.text = QString(self.itemslist[index.row()][4])
			QApplication.style().drawControl(QStyle.CE_ProgressBar, opts, painter)
